@@ -13,11 +13,14 @@ types: list[str] = [
     "AWS::ApiGateway::ApiKey",
     "AWS::ApiGateway::Authorizer",
     "AWS::ApiGateway::BasePathMapping",
+    "AWS::ApiGateway::BasePathMappingV2",
     "AWS::ApiGateway::ClientCertificate",
     "AWS::ApiGateway::Deployment",
     "AWS::ApiGateway::DocumentationPart",
     "AWS::ApiGateway::DocumentationVersion",
     "AWS::ApiGateway::DomainName",
+    "AWS::ApiGateway::DomainNameAccessAssociation",
+    "AWS::ApiGateway::DomainNameV2",
     "AWS::ApiGateway::GatewayResponse",
     "AWS::ApiGateway::Method",
     "AWS::ApiGateway::Model",
@@ -37,6 +40,10 @@ types: list[str] = [
     "AWS::AppConfig::HostedConfigurationVersion",
     "AWS::ApplicationAutoScaling::ScalableTarget",
     "AWS::ApplicationAutoScaling::ScalingPolicy",
+    "AWS::Athena::DataCatalog",
+    "AWS::Athena::NamedQuery",
+    "AWS::Athena::PreparedStatement",
+    "AWS::Athena::WorkGroup",
     "AWS::AutoScaling::AutoScalingGroup",
     "AWS::AutoScaling::LaunchConfiguration",
     "AWS::AutoScaling::LifecycleHook",
@@ -65,6 +72,7 @@ types: list[str] = [
     "AWS::CloudFormation::StackSet",
     "AWS::CloudFormation::WaitCondition",
     "AWS::CloudFormation::WaitConditionHandle",
+    "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
@@ -102,6 +110,10 @@ types: list[str] = [
     "AWS::DataSync::Agent",
     "AWS::DataSync::LocationAzureBlob",
     "AWS::DataSync::LocationEFS",
+    "AWS::DataSync::LocationFSxLustre",
+    "AWS::DataSync::LocationFSxONTAP",
+    "AWS::DataSync::LocationFSxOpenZFS",
+    "AWS::DataSync::LocationFSxWindows",
     "AWS::DataSync::LocationHDFS",
     "AWS::DataSync::LocationNFS",
     "AWS::DataSync::LocationObjectStorage",
@@ -229,6 +241,8 @@ types: list[str] = [
     "AWS::ElasticLoadBalancingV2::ListenerRule",
     "AWS::ElasticLoadBalancingV2::LoadBalancer",
     "AWS::ElasticLoadBalancingV2::TargetGroup",
+    "AWS::ElasticLoadBalancingV2::TrustStore",
+    "AWS::ElasticLoadBalancingV2::TrustStoreRevocation",
     "AWS::Elasticsearch::Domain",
     "AWS::Events::EventBus",
     "AWS::Events::Rule",
@@ -292,6 +306,13 @@ types: list[str] = [
     "AWS::Lambda::LayerVersionPermission",
     "AWS::Lambda::Permission",
     "AWS::Lambda::Version",
+    "AWS::Location::APIKey",
+    "AWS::Location::GeofenceCollection",
+    "AWS::Location::Map",
+    "AWS::Location::PlaceIndex",
+    "AWS::Location::RouteCalculator",
+    "AWS::Location::Tracker",
+    "AWS::Location::TrackerConsumer",
     "AWS::Logs::AccountPolicy",
     "AWS::Logs::Delivery",
     "AWS::Logs::DeliveryDestination",
@@ -303,11 +324,18 @@ types: list[str] = [
     "AWS::Logs::QueryDefinition",
     "AWS::Logs::ResourcePolicy",
     "AWS::Logs::SubscriptionFilter",
+    "AWS::Logs::Transformer",
     "AWS::MSK::BatchScramSecret",
     "AWS::MSK::Cluster",
     "AWS::MSK::ClusterPolicy",
     "AWS::MSK::Configuration",
     "AWS::MSK::VpcConnection",
+    "AWS::Neptune::DBCluster",
+    "AWS::NetworkFirewall::Firewall",
+    "AWS::NetworkFirewall::FirewallPolicy",
+    "AWS::NetworkFirewall::LoggingConfiguration",
+    "AWS::NetworkFirewall::RuleGroup",
+    "AWS::NetworkFirewall::TLSInspectionConfiguration",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
     "AWS::OpenSearchService::Domain",
@@ -346,6 +374,9 @@ types: list[str] = [
     "AWS::Redshift::EventSubscription",
     "AWS::Redshift::ScheduledAction",
     "AWS::ResourceGroups::Group",
+    "AWS::RolesAnywhere::CRL",
+    "AWS::RolesAnywhere::Profile",
+    "AWS::RolesAnywhere::TrustAnchor",
     "AWS::Route53::DNSSEC",
     "AWS::Route53::HealthCheck",
     "AWS::Route53::HostedZone",
@@ -355,8 +386,11 @@ types: list[str] = [
     "AWS::Route53Resolver::FirewallDomainList",
     "AWS::Route53Resolver::FirewallRuleGroup",
     "AWS::Route53Resolver::FirewallRuleGroupAssociation",
+    "AWS::Route53Resolver::ResolverConfig",
     "AWS::Route53Resolver::ResolverQueryLoggingConfig",
     "AWS::Route53Resolver::ResolverQueryLoggingConfigAssociation",
+    "AWS::Route53Resolver::ResolverRule",
+    "AWS::Route53Resolver::ResolverRuleAssociation",
     "AWS::S3::AccessPoint",
     "AWS::S3::Bucket",
     "AWS::S3::BucketPolicy",
@@ -378,6 +412,9 @@ types: list[str] = [
     "AWS::SSM::Parameter",
     "AWS::SSM::PatchBaseline",
     "AWS::SSM::ResourceDataSync",
+    "AWS::SageMaker::ModelCard",
+    "AWS::SageMaker::ModelPackage",
+    "AWS::SageMaker::ModelPackageGroup",
     "AWS::SecretsManager::ResourcePolicy",
     "AWS::SecretsManager::RotationSchedule",
     "AWS::SecretsManager::Secret",
@@ -400,6 +437,13 @@ types: list[str] = [
     "AWS::StepFunctions::StateMachineAlias",
     "AWS::StepFunctions::StateMachineVersion",
     "AWS::Synthetics::Canary",
+    "AWS::Transfer::Agreement",
+    "AWS::Transfer::Certificate",
+    "AWS::Transfer::Connector",
+    "AWS::Transfer::Profile",
+    "AWS::Transfer::Server",
+    "AWS::Transfer::User",
+    "AWS::Transfer::Workflow",
     "AWS::WAF::ByteMatchSet",
     "AWS::WAF::IPSet",
     "AWS::WAF::Rule",
@@ -432,15 +476,19 @@ cached: list[str] = [
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
     "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-basepathmappingv2.json",
     "aws-apigateway-clientcertificate.json",
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
+    "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
+    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -453,15 +501,19 @@ cached: list[str] = [
     "aws-appconfig-hostedconfigurationversion.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
+    "aws-athena-namedquery.json",
+    "aws-athena-preparedstatement.json",
+    "aws-athena-workgroup.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-warmpool.json",
-    "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
     "aws-batch-computeenvironment.json",
+    "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-certificatemanager-certificate.json",
+    "aws-cloudformation-customresource.json",
     "aws-cloudformation-guardhook.json",
     "aws-cloudformation-hookdefaultversion.json",
     "aws-cloudformation-hooktypeconfig.json",
@@ -472,9 +524,11 @@ cached: list[str] = [
     "aws-cloudformation-resourceversion.json",
     "aws-cloudformation-stackset.json",
     "aws-cloudformation-waitconditionhandle.json",
+    "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
+    "aws-cloudfront-distribution.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-keyvaluestore.json",
@@ -502,14 +556,19 @@ cached: list[str] = [
     "aws-datasync-agent.json",
     "aws-datasync-locationazureblob.json",
     "aws-datasync-locationefs.json",
+    "aws-datasync-locationfsxlustre.json",
+    "aws-datasync-locationfsxontap.json",
+    "aws-datasync-locationfsxopenzfs.json",
+    "aws-datasync-locationfsxwindows.json",
     "aws-datasync-locationhdfs.json",
     "aws-datasync-locationnfs.json",
     "aws-datasync-locationobjectstorage.json",
     "aws-datasync-locations3.json",
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
-    "aws-dynamodb-globaltable.json",
+    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
+    "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
     "aws-ec2-ec2fleet.json",
     "aws-ec2-egressonlyinternetgateway.json",
@@ -529,6 +588,7 @@ cached: list[str] = [
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
+    "aws-ec2-networkinterface.json",
     "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-placementgroup.json",
     "aws-ec2-prefixlist.json",
@@ -540,6 +600,7 @@ cached: list[str] = [
     "aws-ec2-securitygroupvpcassociation.json",
     "aws-ec2-snapshotblockpublicaccess.json",
     "aws-ec2-spotfleet.json",
+    "aws-ec2-subnet.json",
     "aws-ec2-subnetcidrblock.json",
     "aws-ec2-subnetroutetableassociation.json",
     "aws-ec2-transitgateway.json",
@@ -580,6 +641,7 @@ cached: list[str] = [
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
+    "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
     "aws-efs-filesystem.json",
@@ -592,17 +654,23 @@ cached: list[str] = [
     "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
+    "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
     "aws-elasticache-serverlesscache.json",
     "aws-elasticache-user.json",
+    "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
     "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
     "aws-elasticloadbalancingv2-targetgroup.json",
+    "aws-elasticloadbalancingv2-truststore.json",
+    "aws-elasticloadbalancingv2-truststorerevocation.json",
     "aws-elasticsearch-domain.json",
+    "aws-emr-cluster.json",
+    "aws-emr-instancefleetconfig.json",
     "aws-emr-instancegroupconfig.json",
     "aws-events-eventbus.json",
     "aws-events-rule.json",
@@ -648,25 +716,45 @@ cached: list[str] = [
     "aws-lakeformation-tag.json",
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
+    "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
     "aws-lambda-function.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-version.json",
+    "aws-location-apikey.json",
+    "aws-location-geofencecollection.json",
+    "aws-location-map.json",
+    "aws-location-placeindex.json",
+    "aws-location-routecalculator.json",
+    "aws-location-tracker.json",
+    "aws-location-trackerconsumer.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
+    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
+    "aws-logs-metricfilter.json",
+    "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
+    "aws-logs-subscriptionfilter.json",
+    "aws-logs-transformer.json",
     "aws-msk-batchscramsecret.json",
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
     "aws-msk-vpcconnection.json",
+    "aws-neptune-dbcluster.json",
+    "aws-networkfirewall-firewall.json",
+    "aws-networkfirewall-firewallpolicy.json",
+    "aws-networkfirewall-loggingconfiguration.json",
+    "aws-networkfirewall-rulegroup.json",
+    "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
+    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-userprofile.json",
@@ -674,12 +762,13 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
+    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-ram-permission.json",
+    "aws-ram-resourceshare.json",
     "aws-rbin-rule.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
-    "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
@@ -697,6 +786,9 @@ cached: list[str] = [
     "aws-redshift-eventsubscription.json",
     "aws-redshift-scheduledaction.json",
     "aws-resourcegroups-group.json",
+    "aws-rolesanywhere-crl.json",
+    "aws-rolesanywhere-profile.json",
+    "aws-rolesanywhere-trustanchor.json",
     "aws-route53-dnssec.json",
     "aws-route53-hostedzone.json",
     "aws-route53-keysigningkey.json",
@@ -705,12 +797,19 @@ cached: list[str] = [
     "aws-route53resolver-firewalldomainlist.json",
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
+    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
+    "aws-route53resolver-resolverruleassociation.json",
+    "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
+    "aws-sagemaker-modelcard.json",
+    "aws-sagemaker-modelpackage.json",
+    "aws-sagemaker-modelpackagegroup.json",
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
@@ -728,6 +827,7 @@ cached: list[str] = [
     "aws-servicediscovery-instance.json",
     "aws-servicediscovery-privatednsnamespace.json",
     "aws-servicediscovery-publicdnsnamespace.json",
+    "aws-servicediscovery-service.json",
     "aws-sns-subscription.json",
     "aws-sns-topic.json",
     "aws-sns-topicinlinepolicy.json",
@@ -736,7 +836,6 @@ cached: list[str] = [
     "aws-sqs-queueinlinepolicy.json",
     "aws-sqs-queuepolicy.json",
     "aws-ssm-association.json",
-    "aws-ssm-document.json",
     "aws-ssm-maintenancewindow.json",
     "aws-ssm-maintenancewindowtarget.json",
     "aws-ssm-maintenancewindowtask.json",
@@ -748,6 +847,13 @@ cached: list[str] = [
     "aws-stepfunctions-statemachinealias.json",
     "aws-stepfunctions-statemachineversion.json",
     "aws-synthetics-canary.json",
+    "aws-transfer-agreement.json",
+    "aws-transfer-certificate.json",
+    "aws-transfer-connector.json",
+    "aws-transfer-profile.json",
+    "aws-transfer-server.json",
+    "aws-transfer-user.json",
+    "aws-transfer-workflow.json",
     "aws-waf-bytematchset.json",
     "aws-waf-sqlinjectionmatchset.json",
     "aws-wafv2-ipset.json",
