@@ -188,6 +188,7 @@ types: list[str] = [
     "AWS::CloudFront::RealtimeLogConfig",
     "AWS::CloudFront::ResponseHeadersPolicy",
     "AWS::CloudFront::StreamingDistribution",
+    "AWS::CloudFront::VpcOrigin",
     "AWS::CloudTrail::Channel",
     "AWS::CloudTrail::Dashboard",
     "AWS::CloudTrail::EventDataStore",
@@ -246,6 +247,7 @@ types: list[str] = [
     "AWS::Connect::ApprovedOrigin",
     "AWS::Connect::ContactFlow",
     "AWS::Connect::ContactFlowModule",
+    "AWS::Connect::ContactFlowVersion",
     "AWS::Connect::EmailAddress",
     "AWS::Connect::EvaluationForm",
     "AWS::Connect::HoursOfOperation",
@@ -275,6 +277,7 @@ types: list[str] = [
     "AWS::CustomerProfiles::CalculatedAttributeDefinition",
     "AWS::CustomerProfiles::Domain",
     "AWS::CustomerProfiles::EventStream",
+    "AWS::CustomerProfiles::EventTrigger",
     "AWS::CustomerProfiles::Integration",
     "AWS::CustomerProfiles::ObjectType",
     "AWS::CustomerProfiles::SegmentDefinition",
@@ -540,6 +543,7 @@ types: list[str] = [
     "AWS::Glue::SchemaVersionMetadata",
     "AWS::Glue::SecurityConfiguration",
     "AWS::Glue::Table",
+    "AWS::Glue::TableOptimizer",
     "AWS::Glue::Trigger",
     "AWS::Glue::UsageProfile",
     "AWS::Glue::Workflow",
@@ -946,6 +950,13 @@ types: list[str] = [
     "AWS::SES::ContactList",
     "AWS::SES::DedicatedIpPool",
     "AWS::SES::EmailIdentity",
+    "AWS::SES::MailManagerAddonInstance",
+    "AWS::SES::MailManagerAddonSubscription",
+    "AWS::SES::MailManagerArchive",
+    "AWS::SES::MailManagerIngressPoint",
+    "AWS::SES::MailManagerRelay",
+    "AWS::SES::MailManagerRuleSet",
+    "AWS::SES::MailManagerTrafficPolicy",
     "AWS::SES::ReceiptFilter",
     "AWS::SES::ReceiptRule",
     "AWS::SES::ReceiptRuleSet",
@@ -1079,6 +1090,7 @@ types: list[str] = [
     "AWS::Transfer::Profile",
     "AWS::Transfer::Server",
     "AWS::Transfer::User",
+    "AWS::Transfer::WebApp",
     "AWS::Transfer::Workflow",
     "AWS::VerifiedPermissions::IdentitySource",
     "AWS::VerifiedPermissions::Policy",
@@ -1208,6 +1220,7 @@ cached: list[str] = [
     "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
+    "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
@@ -1287,6 +1300,7 @@ cached: list[str] = [
     "aws-bedrock-flowversion.json",
     "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
+    "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
     "aws-budgets-budget.json",
@@ -1336,6 +1350,7 @@ cached: list[str] = [
     "aws-cloudfront-realtimelogconfig.json",
     "aws-cloudfront-responseheaderspolicy.json",
     "aws-cloudfront-streamingdistribution.json",
+    "aws-cloudfront-vpcorigin.json",
     "aws-cloudtrail-channel.json",
     "aws-cloudtrail-dashboard.json",
     "aws-cloudtrail-eventdatastore.json",
@@ -1370,7 +1385,6 @@ cached: list[str] = [
     "aws-cognito-managedloginbranding.json",
     "aws-cognito-userpool.json",
     "aws-cognito-userpoolclient.json",
-    "aws-cognito-userpooldomain.json",
     "aws-cognito-userpoolgroup.json",
     "aws-cognito-userpoolidentityprovider.json",
     "aws-cognito-userpoolresourceserver.json",
@@ -1423,6 +1437,7 @@ cached: list[str] = [
     "aws-customerprofiles-calculatedattributedefinition.json",
     "aws-customerprofiles-domain.json",
     "aws-customerprofiles-eventstream.json",
+    "aws-customerprofiles-eventtrigger.json",
     "aws-customerprofiles-integration.json",
     "aws-customerprofiles-objecttype.json",
     "aws-customerprofiles-segmentdefinition.json",
@@ -1481,6 +1496,7 @@ cached: list[str] = [
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
     "aws-docdbelastic-cluster.json",
+    "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
@@ -1609,6 +1625,7 @@ cached: list[str] = [
     "aws-elasticache-serverlesscache.json",
     "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
+    "aws-elasticache-usergroup.json",
     "aws-elasticbeanstalk-application.json",
     "aws-elasticbeanstalk-applicationversion.json",
     "aws-elasticbeanstalk-configurationtemplate.json",
@@ -1681,6 +1698,7 @@ cached: list[str] = [
     "aws-glue-schemaversionmetadata.json",
     "aws-glue-securityconfiguration.json",
     "aws-glue-table.json",
+    "aws-glue-tableoptimizer.json",
     "aws-glue-trigger.json",
     "aws-glue-usageprofile.json",
     "aws-glue-workflow.json",
@@ -1993,7 +2011,6 @@ cached: list[str] = [
     "aws-rds-customdbengineversion.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
-    "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
     "aws-rds-dbproxy.json",
     "aws-rds-dbproxyendpoint.json",
@@ -2055,10 +2072,8 @@ cached: list[str] = [
     "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
-    "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
-    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3-multiregionaccesspoint.json",
     "aws-s3-multiregionaccesspointpolicy.json",
@@ -2151,6 +2166,13 @@ cached: list[str] = [
     "aws-ses-contactlist.json",
     "aws-ses-dedicatedippool.json",
     "aws-ses-emailidentity.json",
+    "aws-ses-mailmanageraddoninstance.json",
+    "aws-ses-mailmanageraddonsubscription.json",
+    "aws-ses-mailmanagerarchive.json",
+    "aws-ses-mailmanageringresspoint.json",
+    "aws-ses-mailmanagerrelay.json",
+    "aws-ses-mailmanagerruleset.json",
+    "aws-ses-mailmanagertrafficpolicy.json",
     "aws-ses-receiptfilter.json",
     "aws-ses-receiptrule.json",
     "aws-ses-receiptruleset.json",
@@ -2201,12 +2223,14 @@ cached: list[str] = [
     "aws-synthetics-canary.json",
     "aws-synthetics-group.json",
     "aws-systemsmanagersap-application.json",
+    "aws-timestream-influxdbinstance.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
     "aws-transfer-connector.json",
     "aws-transfer-profile.json",
     "aws-transfer-server.json",
     "aws-transfer-user.json",
+    "aws-transfer-webapp.json",
     "aws-transfer-workflow.json",
     "aws-verifiedpermissions-identitysource.json",
     "aws-verifiedpermissions-policy.json",
@@ -2244,9 +2268,11 @@ cached: list[str] = [
     "aws-wafv2-rulegroup.json",
     "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
+    "aws-wisdom-aiagent.json",
     "aws-wisdom-aiagentversion.json",
     "aws-wisdom-aiguardrail.json",
     "aws-wisdom-aiguardrailversion.json",
+    "aws-wisdom-aiprompt.json",
     "aws-wisdom-aipromptversion.json",
     "aws-wisdom-assistant.json",
     "aws-wisdom-assistantassociation.json",
