@@ -136,6 +136,7 @@ types: list[str] = [
     "AWS::CloudFront::PublicKey",
     "AWS::CloudFront::RealtimeLogConfig",
     "AWS::CloudFront::ResponseHeadersPolicy",
+    "AWS::CloudFront::VpcOrigin",
     "AWS::CloudTrail::Dashboard",
     "AWS::CloudTrail::EventDataStore",
     "AWS::CloudTrail::ResourcePolicy",
@@ -161,6 +162,7 @@ types: list[str] = [
     "AWS::Cognito::ManagedLoginBranding",
     "AWS::Cognito::UserPool",
     "AWS::Cognito::UserPoolClient",
+    "AWS::Cognito::UserPoolDomain",
     "AWS::Cognito::UserPoolGroup",
     "AWS::Cognito::UserPoolIdentityProvider",
     "AWS::Cognito::UserPoolResourceServer",
@@ -618,6 +620,7 @@ types: list[str] = [
     "AWS::SSM::MaintenanceWindowTask",
     "AWS::SSM::Parameter",
     "AWS::SSM::PatchBaseline",
+    "AWS::SSM::ResourceDataSync",
     "AWS::SSO::Application",
     "AWS::SSO::ApplicationAssignment",
     "AWS::SSO::Assignment",
@@ -695,6 +698,7 @@ types: list[str] = [
     "AWS::Transfer::Profile",
     "AWS::Transfer::Server",
     "AWS::Transfer::User",
+    "AWS::Transfer::WebApp",
     "AWS::Transfer::Workflow",
     "AWS::VerifiedPermissions::IdentitySource",
     "AWS::VerifiedPermissions::Policy",
@@ -776,6 +780,7 @@ cached: list[str] = [
     "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
+    "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
@@ -861,6 +866,7 @@ cached: list[str] = [
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-realtimelogconfig.json",
     "aws-cloudfront-responseheaderspolicy.json",
+    "aws-cloudfront-vpcorigin.json",
     "aws-cloudtrail-dashboard.json",
     "aws-cloudtrail-eventdatastore.json",
     "aws-cloudtrail-resourcepolicy.json",
@@ -927,6 +933,7 @@ cached: list[str] = [
     "aws-docdb-dbinstance.json",
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
+    "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
@@ -1038,6 +1045,7 @@ cached: list[str] = [
     "aws-elasticache-securitygroupingress.json",
     "aws-elasticache-serverlesscache.json",
     "aws-elasticache-user.json",
+    "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
     "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
@@ -1172,6 +1180,7 @@ cached: list[str] = [
     "aws-logs-transformer.json",
     "aws-m2-application.json",
     "aws-m2-deployment.json",
+    "aws-m2-environment.json",
     "aws-memorydb-acl.json",
     "aws-memorydb-parametergroup.json",
     "aws-memorydb-subnetgroup.json",
@@ -1229,7 +1238,6 @@ cached: list[str] = [
     "aws-rbin-rule.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
-    "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
     "aws-rds-dbproxy.json",
     "aws-rds-dbproxyendpoint.json",
@@ -1285,7 +1293,6 @@ cached: list[str] = [
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
-    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
@@ -1351,12 +1358,12 @@ cached: list[str] = [
     "aws-sqs-queueinlinepolicy.json",
     "aws-sqs-queuepolicy.json",
     "aws-ssm-association.json",
-    "aws-ssm-document.json",
     "aws-ssm-maintenancewindow.json",
     "aws-ssm-maintenancewindowtarget.json",
     "aws-ssm-maintenancewindowtask.json",
     "aws-ssm-parameter.json",
     "aws-ssm-patchbaseline.json",
+    "aws-ssm-resourcedatasync.json",
     "aws-sso-application.json",
     "aws-sso-applicationassignment.json",
     "aws-sso-assignment.json",
@@ -1369,12 +1376,14 @@ cached: list[str] = [
     "aws-stepfunctions-statemachineversion.json",
     "aws-synthetics-canary.json",
     "aws-systemsmanagersap-application.json",
+    "aws-timestream-influxdbinstance.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
     "aws-transfer-connector.json",
     "aws-transfer-profile.json",
     "aws-transfer-server.json",
     "aws-transfer-user.json",
+    "aws-transfer-webapp.json",
     "aws-transfer-workflow.json",
     "aws-verifiedpermissions-identitysource.json",
     "aws-verifiedpermissions-policy.json",
