@@ -133,6 +133,7 @@ types: list[str] = [
     "AWS::CloudFront::PublicKey",
     "AWS::CloudFront::RealtimeLogConfig",
     "AWS::CloudFront::ResponseHeadersPolicy",
+    "AWS::CloudFront::VpcOrigin",
     "AWS::CloudTrail::Dashboard",
     "AWS::CloudTrail::EventDataStore",
     "AWS::CloudTrail::ResourcePolicy",
@@ -609,6 +610,7 @@ types: list[str] = [
     "AWS::SSM::MaintenanceWindowTask",
     "AWS::SSM::Parameter",
     "AWS::SSM::PatchBaseline",
+    "AWS::SSM::ResourceDataSync",
     "AWS::SSO::Application",
     "AWS::SSO::ApplicationAssignment",
     "AWS::SSO::Assignment",
@@ -683,6 +685,7 @@ types: list[str] = [
     "AWS::Transfer::Profile",
     "AWS::Transfer::Server",
     "AWS::Transfer::User",
+    "AWS::Transfer::WebApp",
     "AWS::Transfer::Workflow",
     "AWS::VerifiedPermissions::IdentitySource",
     "AWS::VerifiedPermissions::Policy",
@@ -762,6 +765,7 @@ cached: list[str] = [
     "aws-apigatewayv2-stage.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
+    "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
@@ -789,13 +793,11 @@ cached: list[str] = [
     "aws-appsync-sourceapiassociation.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
-    "aws-athena-datacatalog.json",
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-warmpool.json",
-    "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
     "aws-backup-logicallyairgappedbackupvault.json",
@@ -823,6 +825,7 @@ cached: list[str] = [
     "aws-cloudformation-resourceversion.json",
     "aws-cloudformation-stack.json",
     "aws-cloudformation-stackset.json",
+    "aws-cloudformation-typeactivation.json",
     "aws-cloudformation-waitconditionhandle.json",
     "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
@@ -838,6 +841,7 @@ cached: list[str] = [
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-realtimelogconfig.json",
     "aws-cloudfront-responseheaderspolicy.json",
+    "aws-cloudfront-vpcorigin.json",
     "aws-cloudtrail-dashboard.json",
     "aws-cloudtrail-eventdatastore.json",
     "aws-cloudtrail-resourcepolicy.json",
@@ -862,7 +866,6 @@ cached: list[str] = [
     "aws-cognito-managedloginbranding.json",
     "aws-cognito-userpool.json",
     "aws-cognito-userpoolclient.json",
-    "aws-cognito-userpooldomain.json",
     "aws-cognito-userpoolgroup.json",
     "aws-cognito-userpoolidentityprovider.json",
     "aws-cognito-userpoolresourceserver.json",
@@ -1017,6 +1020,7 @@ cached: list[str] = [
     "aws-elasticache-securitygroupingress.json",
     "aws-elasticache-serverlesscache.json",
     "aws-elasticache-user.json",
+    "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
     "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
@@ -1038,6 +1042,7 @@ cached: list[str] = [
     "aws-fms-notificationchannel.json",
     "aws-fms-policy.json",
     "aws-fsx-datarepositoryassociation.json",
+    "aws-fsx-filesystem.json",
     "aws-fsx-snapshot.json",
     "aws-fsx-storagevirtualmachine.json",
     "aws-fsx-volume.json",
@@ -1047,7 +1052,6 @@ cached: list[str] = [
     "aws-globalaccelerator-listener.json",
     "aws-glue-classifier.json",
     "aws-glue-connection.json",
-    "aws-glue-crawler.json",
     "aws-glue-customentitytype.json",
     "aws-glue-database.json",
     "aws-glue-datacatalogencryptionsettings.json",
@@ -1125,6 +1129,7 @@ cached: list[str] = [
     "aws-logs-transformer.json",
     "aws-m2-application.json",
     "aws-m2-deployment.json",
+    "aws-m2-environment.json",
     "aws-macie-allowlist.json",
     "aws-macie-customdataidentifier.json",
     "aws-macie-findingsfilter.json",
@@ -1183,7 +1188,6 @@ cached: list[str] = [
     "aws-rbin-rule.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
-    "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
     "aws-rds-dbproxy.json",
     "aws-rds-dbproxyendpoint.json",
@@ -1206,6 +1210,7 @@ cached: list[str] = [
     "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
+    "aws-redshiftserverless-workgroup.json",
     "aws-rekognition-collection.json",
     "aws-resourceexplorer2-defaultviewassociation.json",
     "aws-resourceexplorer2-index.json",
@@ -1213,6 +1218,7 @@ cached: list[str] = [
     "aws-resourcegroups-group.json",
     "aws-resourcegroups-tagsynctask.json",
     "aws-rolesanywhere-crl.json",
+    "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
     "aws-route53-dnssec.json",
     "aws-route53-hostedzone.json",
@@ -1237,7 +1243,6 @@ cached: list[str] = [
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
-    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
@@ -1247,7 +1252,6 @@ cached: list[str] = [
     "aws-s3outposts-endpoint.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
-    "aws-sagemaker-domain.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
     "aws-sagemaker-imageversion.json",
@@ -1259,7 +1263,6 @@ cached: list[str] = [
     "aws-sagemaker-project.json",
     "aws-sagemaker-space.json",
     "aws-sagemaker-studiolifecycleconfig.json",
-    "aws-sagemaker-userprofile.json",
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
@@ -1293,6 +1296,7 @@ cached: list[str] = [
     "aws-servicediscovery-privatednsnamespace.json",
     "aws-servicediscovery-publicdnsnamespace.json",
     "aws-servicediscovery-service.json",
+    "aws-ses-configurationset.json",
     "aws-ses-configurationseteventdestination.json",
     "aws-ses-contactlist.json",
     "aws-ses-dedicatedippool.json",
@@ -1312,12 +1316,12 @@ cached: list[str] = [
     "aws-sqs-queue.json",
     "aws-sqs-queueinlinepolicy.json",
     "aws-ssm-association.json",
-    "aws-ssm-document.json",
     "aws-ssm-maintenancewindow.json",
     "aws-ssm-maintenancewindowtarget.json",
     "aws-ssm-maintenancewindowtask.json",
     "aws-ssm-parameter.json",
     "aws-ssm-patchbaseline.json",
+    "aws-ssm-resourcedatasync.json",
     "aws-sso-application.json",
     "aws-sso-applicationassignment.json",
     "aws-sso-assignment.json",
@@ -1336,6 +1340,7 @@ cached: list[str] = [
     "aws-transfer-profile.json",
     "aws-transfer-server.json",
     "aws-transfer-user.json",
+    "aws-transfer-webapp.json",
     "aws-transfer-workflow.json",
     "aws-verifiedpermissions-identitysource.json",
     "aws-verifiedpermissions-policy.json",
